@@ -7,8 +7,7 @@
 #' at the county, tract, block, or place level. Census data calculated are
 #' Pr(Geolocation | Race) where geolocation is county, tract, block, or place.
 #'
-#' @param key A required character object. Must contain user's Census API
-#'  key, which can be requested \href{https://api.census.gov/data/key_signup.html}{here}.
+#' @inheritParams get_census_data
 #' @param voter.file An object of class \code{data.frame}. Must contain field(s) named
 #'  \code{\var{county}}, \code{\var{tract}}, \code{\var{block}}, and/or \code{\var{place}}
 #'  specifying geolocation. These should be character variables that match up with
@@ -30,7 +29,7 @@
 #'  If \code{TRUE}, function will return Pr(Geolocation, Sex | Race).
 #'  If \code{\var{age}} is also \code{TRUE}, function will return Pr(Geolocation, Age, Sex | Race).
 #' @param year A character object specifying the year of U.S. Census data to be downloaded.
-#'  Use \code{"2010"}, or \code{"2020"}. Default is \code{"2010"}.
+#'  Use \code{"2010"}, or \code{"2020"}. Default is \code{"2020"}.
 #'  Warning: 2020 U.S. Census data is downloaded only when \code{\var{age}} and
 #'  \code{\var{sex}} are both \code{FALSE}.
 #' @param census.data A optional census object of class \code{list} containing
@@ -54,24 +53,35 @@
 #' data(voters)
 #' }
 #' \dontrun{
-#' census_helper(key = "...", voter.file = voters, states = "nj", geo = "block")
+#' census_helper(voter.file = voters, states = "nj", geo = "block")
 #' }
 #' \dontrun{
 #' census_helper(
-#'   key = "...", voter.file = voters, states = "all", geo = "tract",
+#'   voter.file = voters, states = "all", geo = "tract",
 #'   age = TRUE, sex = TRUE
 #' )
 #' }
 #' \dontrun{
 #' census_helper(
-#'   key = "...", voter.file = voters, states = "all", geo = "county",
+#'   voter.file = voters, states = "all", geo = "county",
 #'   age = FALSE, sex = FALSE, year = "2020"
 #' )
 #' }
 #'
 #' @keywords internal
 
-census_helper <- function(key, voter.file, states = "all", geo = "tract", age = FALSE, sex = FALSE, year = "2010", census.data = NULL, retry = 3, use.counties = FALSE) {
+census_helper <- function(
+    key = Sys.getenv("CENSUS_API_KEY"),
+    voter.file,
+    states = "all",
+    geo = "tract",
+    age = FALSE,
+    sex = FALSE,
+    year = "2020",
+    census.data = NULL,
+    retry = 3,
+    use.counties = FALSE
+) {
   if (is.null(census.data) || (typeof(census.data) != "list")) {
     toDownload <- TRUE
   } else {
@@ -79,9 +89,7 @@ census_helper <- function(key, voter.file, states = "all", geo = "tract", age =
   }
 
   if (toDownload) {
-    if (missing(key)) {
-      stop("Must enter U.S. Census API key, which can be requested at https://api.census.gov/data/key_signup.html.")
-    }
+    key <- validate_key(key)
   }
 
   states <- toupper(states)
